Crate livox2_sys

Structs

DirectLidarStateInfo
FovCfg
FuncIOCfg
HostImuDataIPInfo
HostPointIPInfo
HostStateInfoIpInfo
LivoxIpCfg
LivoxLidarAsyncControlResponse
LivoxLidarCartesianHighRawPoint
LivoxLidarCartesianLowRawPoint
LivoxLidarCmdPacket
LivoxLidarDiagInternalInfoResponse
LivoxLidarEthernetPacket
LivoxLidarImuRawPoint
LivoxLidarInfo
LivoxLidarInfoResponse
LivoxLidarInstallAttitude
LivoxLidarIpInfo
LivoxLidarKeyValueParam
LivoxLidarLogParam
LivoxLidarLoggerCfgInfo
LivoxLidarLoggerResponse
LivoxLidarQueryInternalInfoResponse
LivoxLidarRebootRequest
LivoxLidarRebootResponse
LivoxLidarResetRequest
LivoxLidarResetResponse
LivoxLidarRmcSyncTimeResponse
LivoxLidarSdkVer
The numeric version information struct.
LivoxLidarSpherPoint
LivoxLidarStateInfo
LivoxLidarUpgradeState
__atomic_wide_counter__bindgen_ty_1
__fsid_t
__once_flag
__pthread_cond_s
__pthread_internal_list
__pthread_internal_slist
__pthread_mutex_s
__pthread_rwlock_arch_t
__sigset_t
epoll_event
fd_set
itimerval
timespec
timeval
timezone

Constants

BIG_ENDIAN
BYTE_ORDER
CLOSE_RANGE_CLOEXEC
CLOSE_RANGE_UNSHARE
EPOLL_CLOEXEC
EPOLL_CTL_ADD
EPOLL_CTL_DEL
EPOLL_CTL_MOD
EPOLL_EVENTS_EPOLLERR
EPOLL_EVENTS_EPOLLET
EPOLL_EVENTS_EPOLLEXCLUSIVE
EPOLL_EVENTS_EPOLLHUP
EPOLL_EVENTS_EPOLLIN
EPOLL_EVENTS_EPOLLMSG
EPOLL_EVENTS_EPOLLONESHOT
EPOLL_EVENTS_EPOLLOUT
EPOLL_EVENTS_EPOLLPRI
EPOLL_EVENTS_EPOLLRDBAND
EPOLL_EVENTS_EPOLLRDHUP
EPOLL_EVENTS_EPOLLRDNORM
EPOLL_EVENTS_EPOLLWAKEUP
EPOLL_EVENTS_EPOLLWRBAND
EPOLL_EVENTS_EPOLLWRNORM
FD_SETSIZE
F_LOCK
F_OK
F_TEST
F_TLOCK
F_ULOCK
HAVE_EPOLL
INT8_MAX
INT8_MIN
INT8_WIDTH
INT16_MAX
INT16_MIN
INT16_WIDTH
INT32_MAX
INT32_MIN
INT32_WIDTH
INT64_WIDTH
INTMAX_WIDTH
INTPTR_MAX
INTPTR_MIN
INTPTR_WIDTH
INT_FAST8_MAX
INT_FAST8_MIN
INT_FAST8_WIDTH
INT_FAST16_MAX
INT_FAST16_MIN
INT_FAST16_WIDTH
INT_FAST32_MAX
INT_FAST32_MIN
INT_FAST32_WIDTH
INT_FAST64_WIDTH
INT_LEAST8_MAX
INT_LEAST8_MIN
INT_LEAST8_WIDTH
INT_LEAST16_MAX
INT_LEAST16_MIN
INT_LEAST16_WIDTH
INT_LEAST32_MAX
INT_LEAST32_MIN
INT_LEAST32_WIDTH
INT_LEAST64_WIDTH
LITTLE_ENDIAN
LIVOX_LIDAR_SDK_MAJOR_VERSION
LIVOX_LIDAR_SDK_MINOR_VERSION
LIVOX_LIDAR_SDK_PATCH_VERSION
L_INCR
L_SET
L_XTND
LivoxLidarDetectMode_kLivoxLidarDetectNormal
LivoxLidarDetectMode_kLivoxLidarDetectSensitive
LivoxLidarDeviceType_kLivoxLidarTypeAvia
LivoxLidarDeviceType_kLivoxLidarTypeHAP
LivoxLidarDeviceType_kLivoxLidarTypeHorizon
LivoxLidarDeviceType_kLivoxLidarTypeHub
LivoxLidarDeviceType_kLivoxLidarTypeIndustrialHAP
LivoxLidarDeviceType_kLivoxLidarTypeMid40
LivoxLidarDeviceType_kLivoxLidarTypeMid70
LivoxLidarDeviceType_kLivoxLidarTypeMid360
LivoxLidarDeviceType_kLivoxLidarTypePA
LivoxLidarDeviceType_kLivoxLidarTypeTele
LivoxLidarFsmEvent_kLivoxLidarEventComplete
LivoxLidarFsmEvent_kLivoxLidarEventCompleteXferFirmware
LivoxLidarFsmEvent_kLivoxLidarEventErr
LivoxLidarFsmEvent_kLivoxLidarEventGetUpgradeProgress
LivoxLidarFsmEvent_kLivoxLidarEventReinit
LivoxLidarFsmEvent_kLivoxLidarEventRequestUpgrade
LivoxLidarFsmEvent_kLivoxLidarEventTimeout
LivoxLidarFsmEvent_kLivoxLidarEventUndef
LivoxLidarFsmEvent_kLivoxLidarEventXferFirmware
LivoxLidarFsmState_kLivoxLidarUpgradeComplete
LivoxLidarFsmState_kLivoxLidarUpgradeCompleteXferFirmware
LivoxLidarFsmState_kLivoxLidarUpgradeErr
LivoxLidarFsmState_kLivoxLidarUpgradeGetUpgradeProgress
LivoxLidarFsmState_kLivoxLidarUpgradeIdle
LivoxLidarFsmState_kLivoxLidarUpgradeRequest
LivoxLidarFsmState_kLivoxLidarUpgradeTimeout
LivoxLidarFsmState_kLivoxLidarUpgradeUndef
LivoxLidarFsmState_kLivoxLidarUpgradeXferFirmware
LivoxLidarGlassHeat_kLivoxLidarDiagnosticHeating
LivoxLidarGlassHeat_kLivoxLidarStopPowerOnHeatingOrDiagnosticHeating
LivoxLidarGlassHeat_kLivoxLidarStopSelfHeating
LivoxLidarGlassHeat_kLivoxLidarTurnOnHeating
LivoxLidarLogType_kLivoxLidarExceptionLog
LivoxLidarLogType_kLivoxLidarRealTimeLog
LivoxLidarPointDataType_kLivoxLidarCartesianCoordinateHighData
LivoxLidarPointDataType_kLivoxLidarCartesianCoordinateLowData
LivoxLidarPointDataType_kLivoxLidarImuData
LivoxLidarPointDataType_kLivoxLidarSphericalCoordinateData
LivoxLidarPointFrameRate_kLivoxLidarFrameRate10Hz
LivoxLidarPointFrameRate_kLivoxLidarFrameRate15Hz
LivoxLidarPointFrameRate_kLivoxLidarFrameRate20Hz
LivoxLidarPointFrameRate_kLivoxLidarFrameRate25Hz
LivoxLidarScanPattern_kLivoxLidarScanPatternNoneRepetive
LivoxLidarScanPattern_kLivoxLidarScanPatternRepetive
LivoxLidarScanPattern_kLivoxLidarScanPatternRepetiveLowFrameRate
LivoxLidarStatus_kLivoxLidarStatusChannelNotExist
< Command channel not exist.
LivoxLidarStatus_kLivoxLidarStatusFailure
< Failure.
LivoxLidarStatus_kLivoxLidarStatusHandlerImplNotExist
< Handler implementation not exist.
LivoxLidarStatus_kLivoxLidarStatusInvalidHandle
< Device handle invalid.
LivoxLidarStatus_kLivoxLidarStatusNotConnected
< Requested device is not connected.
LivoxLidarStatus_kLivoxLidarStatusNotEnoughMemory
< No enough memory.
LivoxLidarStatus_kLivoxLidarStatusNotSupported
< Operation is not supported on this device.
LivoxLidarStatus_kLivoxLidarStatusSendFailed
< Command send failed.
LivoxLidarStatus_kLivoxLidarStatusSuccess
< Success.
LivoxLidarStatus_kLivoxLidarStatusTimeout
< Operation timeouts.
LivoxLidarWorkModeAfterBoot_kLivoxLidarWorkModeAfterBootDefault
LivoxLidarWorkModeAfterBoot_kLivoxLidarWorkModeAfterBootNormal
LivoxLidarWorkModeAfterBoot_kLivoxLidarWorkModeAfterBootWakeUp
LivoxLidarWorkMode_kLivoxLidarError
LivoxLidarWorkMode_kLivoxLidarMotorStarting
LivoxLidarWorkMode_kLivoxLidarMotorStoping
LivoxLidarWorkMode_kLivoxLidarNormal
LivoxLidarWorkMode_kLivoxLidarPowerOnSelfTest
LivoxLidarWorkMode_kLivoxLidarSleep
LivoxLidarWorkMode_kLivoxLidarUpgrade
LivoxLidarWorkMode_kLivoxLidarWakeUp
PDP_ENDIAN
PTRDIFF_MAX
PTRDIFF_MIN
PTRDIFF_WIDTH
ParamKeyName_kKeyBlindSpotSet
ParamKeyName_kKeyCoreTemp
ParamKeyName_kKeyCtlHostIpCfg
ParamKeyName_kKeyCurGlassHeatState
ParamKeyName_kKeyCurWorkState
ParamKeyName_kKeyDetectMode
ParamKeyName_kKeyDualEmitEn
ParamKeyName_kKeyEnvironmentTemp
ParamKeyName_kKeyForceHeatEn
ParamKeyName_kKeyFovCfg0
ParamKeyName_kKeyFovCfg1
ParamKeyName_kKeyFovCfgEn
ParamKeyName_kKeyFrameRate
ParamKeyName_kKeyFuncIoCfg
ParamKeyName_kKeyFusaEn
ParamKeyName_kKeyFwType
ParamKeyName_kKeyGlassHeat
ParamKeyName_kKeyHmsCode
ParamKeyName_kKeyImuDataEn
ParamKeyName_kKeyInstallAttitude
ParamKeyName_kKeyLastSyncTime
ParamKeyName_kKeyLidarDiagInfoQuery
ParamKeyName_kKeyLidarDiagStatus
ParamKeyName_kKeyLidarFlashStatus
ParamKeyName_kKeyLidarImuHostIpCfg
ParamKeyName_kKeyLidarIpCfg
ParamKeyName_kKeyLidarPointDataHostIpCfg
ParamKeyName_kKeyLocalTimeNow
ParamKeyName_kKeyLogHostIpCfg
ParamKeyName_kKeyLogParamSet
ParamKeyName_kKeyMac
ParamKeyName_kKeyPatternMode
ParamKeyName_kKeyPclDataType
ParamKeyName_kKeyPointSendEn
ParamKeyName_kKeyPowerUpCnt
ParamKeyName_kKeyProductInfo
ParamKeyName_kKeyRoiMode
ParamKeyName_kKeySn
ParamKeyName_kKeyStateInfoHostIpCfg
ParamKeyName_kKeyStatusCode
ParamKeyName_kKeyTimeOffset
ParamKeyName_kKeyTimeSyncType
ParamKeyName_kKeyVehicleSpeed
ParamKeyName_kKeyVersionApp
ParamKeyName_kKeyVersionHardware
ParamKeyName_kKeyVersionLoader
ParamKeyName_kKeyWorkMode
ParamKeyName_kKeyWorkModeAfterBoot
R_OK
SEEK_CUR
SEEK_DATA
SEEK_END
SEEK_HOLE
SEEK_SET
SIG_ATOMIC_MAX
SIG_ATOMIC_MIN
SIG_ATOMIC_WIDTH
SIZE_MAX
SIZE_WIDTH
STDERR_FILENO
STDIN_FILENO
STDOUT_FILENO
UINT8_MAX
UINT8_WIDTH
UINT16_MAX
UINT16_WIDTH
UINT32_MAX
UINT32_WIDTH
UINT64_WIDTH
UINTMAX_WIDTH
UINTPTR_MAX
UINTPTR_WIDTH
UINT_FAST8_MAX
UINT_FAST8_WIDTH
UINT_FAST16_MAX
UINT_FAST16_WIDTH
UINT_FAST32_MAX
UINT_FAST32_WIDTH
UINT_FAST64_WIDTH
UINT_LEAST8_MAX
UINT_LEAST8_WIDTH
UINT_LEAST16_MAX
UINT_LEAST16_WIDTH
UINT_LEAST32_MAX
UINT_LEAST32_WIDTH
UINT_LEAST64_WIDTH
WCHAR_WIDTH
WINT_MAX
WINT_MIN
WINT_WIDTH
W_OK
X_OK
_ATFILE_SOURCE
_BITS_BYTESWAP_H
_BITS_ENDIANNESS_H
_BITS_ENDIAN_H
_BITS_POSIX_OPT_H
_BITS_PTHREADTYPES_ARCH_H
_BITS_PTHREADTYPES_COMMON_H
_BITS_STDINT_INTN_H
_BITS_STDINT_LEAST_H
_BITS_STDINT_UINTN_H
_BITS_TIME64_H
_BITS_TYPESIZES_H
_BITS_TYPES_H
_BITS_UINTN_IDENTITY_H
_BITS_WCHAR_H
_CS_GNU_LIBC_VERSION
_CS_GNU_LIBPTHREAD_VERSION
_CS_LFS64_CFLAGS
_CS_LFS64_LDFLAGS
_CS_LFS64_LIBS
_CS_LFS64_LINTFLAGS
_CS_LFS_CFLAGS
_CS_LFS_LDFLAGS
_CS_LFS_LIBS
_CS_LFS_LINTFLAGS
_CS_PATH
_CS_POSIX_V6_ILP32_OFF32_CFLAGS
_CS_POSIX_V6_ILP32_OFF32_LDFLAGS
_CS_POSIX_V6_ILP32_OFF32_LIBS
_CS_POSIX_V6_ILP32_OFF32_LINTFLAGS
_CS_POSIX_V6_ILP32_OFFBIG_CFLAGS
_CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS
_CS_POSIX_V6_ILP32_OFFBIG_LIBS
_CS_POSIX_V6_ILP32_OFFBIG_LINTFLAGS
_CS_POSIX_V6_LP64_OFF64_CFLAGS
_CS_POSIX_V6_LP64_OFF64_LDFLAGS
_CS_POSIX_V6_LP64_OFF64_LIBS
_CS_POSIX_V6_LP64_OFF64_LINTFLAGS
_CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS
_CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS
_CS_POSIX_V6_LPBIG_OFFBIG_LIBS
_CS_POSIX_V6_LPBIG_OFFBIG_LINTFLAGS
_CS_POSIX_V7_ILP32_OFF32_CFLAGS
_CS_POSIX_V7_ILP32_OFF32_LDFLAGS
_CS_POSIX_V7_ILP32_OFF32_LIBS
_CS_POSIX_V7_ILP32_OFF32_LINTFLAGS
_CS_POSIX_V7_ILP32_OFFBIG_CFLAGS
_CS_POSIX_V7_ILP32_OFFBIG_LDFLAGS
_CS_POSIX_V7_ILP32_OFFBIG_LIBS
_CS_POSIX_V7_ILP32_OFFBIG_LINTFLAGS
_CS_POSIX_V7_LP64_OFF64_CFLAGS
_CS_POSIX_V7_LP64_OFF64_LDFLAGS
_CS_POSIX_V7_LP64_OFF64_LIBS
_CS_POSIX_V7_LP64_OFF64_LINTFLAGS
_CS_POSIX_V7_LPBIG_OFFBIG_CFLAGS
_CS_POSIX_V7_LPBIG_OFFBIG_LDFLAGS
_CS_POSIX_V7_LPBIG_OFFBIG_LIBS
_CS_POSIX_V7_LPBIG_OFFBIG_LINTFLAGS
_CS_V5_WIDTH_RESTRICTED_ENVS
_CS_V6_ENV
_CS_V6_WIDTH_RESTRICTED_ENVS
_CS_V7_ENV
_CS_V7_WIDTH_RESTRICTED_ENVS
_CS_XBS5_ILP32_OFF32_CFLAGS
_CS_XBS5_ILP32_OFF32_LDFLAGS
_CS_XBS5_ILP32_OFF32_LIBS
_CS_XBS5_ILP32_OFF32_LINTFLAGS
_CS_XBS5_ILP32_OFFBIG_CFLAGS
_CS_XBS5_ILP32_OFFBIG_LDFLAGS
_CS_XBS5_ILP32_OFFBIG_LIBS
_CS_XBS5_ILP32_OFFBIG_LINTFLAGS
_CS_XBS5_LP64_OFF64_CFLAGS
_CS_XBS5_LP64_OFF64_LDFLAGS
_CS_XBS5_LP64_OFF64_LIBS
_CS_XBS5_LP64_OFF64_LINTFLAGS
_CS_XBS5_LPBIG_OFFBIG_CFLAGS
_CS_XBS5_LPBIG_OFFBIG_LDFLAGS
_CS_XBS5_LPBIG_OFFBIG_LIBS
_CS_XBS5_LPBIG_OFFBIG_LINTFLAGS
_DEFAULT_SOURCE
_DYNAMIC_STACK_SIZE_SOURCE
_ENDIAN_H
_FEATURES_H
_GETOPT_CORE_H
_GETOPT_POSIX_H
_ISOC2X_SOURCE
_ISOC11_SOURCE
_ISOC95_SOURCE
_ISOC99_SOURCE
_LARGEFILE64_SOURCE
_LARGEFILE_SOURCE
_LFS64_ASYNCHRONOUS_IO
_LFS64_LARGEFILE
_LFS64_STDIO
_LFS_ASYNCHRONOUS_IO
_LFS_LARGEFILE
_PC_2_SYMLINKS
_PC_ALLOC_SIZE_MIN
_PC_ASYNC_IO
_PC_CHOWN_RESTRICTED
_PC_FILESIZEBITS
_PC_LINK_MAX
_PC_MAX_CANON
_PC_MAX_INPUT
_PC_NAME_MAX
_PC_NO_TRUNC
_PC_PATH_MAX
_PC_PIPE_BUF
_PC_PRIO_IO
_PC_REC_INCR_XFER_SIZE
_PC_REC_MAX_XFER_SIZE
_PC_REC_MIN_XFER_SIZE
_PC_REC_XFER_ALIGN
_PC_SOCK_MAXBUF
_PC_SYMLINK_MAX
_PC_SYNC_IO
_PC_VDISABLE
_POSIX2_CHAR_TERM
_POSIX2_C_BIND
_POSIX2_C_DEV
_POSIX2_C_VERSION
_POSIX2_LOCALEDEF
_POSIX2_SW_DEV
_POSIX2_VERSION
_POSIX_ADVISORY_INFO
_POSIX_ASYNCHRONOUS_IO
_POSIX_ASYNC_IO
_POSIX_BARRIERS
_POSIX_CHOWN_RESTRICTED
_POSIX_CLOCK_SELECTION
_POSIX_CPUTIME
_POSIX_C_SOURCE
_POSIX_FSYNC
_POSIX_IPV6
_POSIX_JOB_CONTROL
_POSIX_MAPPED_FILES
_POSIX_MEMLOCK
_POSIX_MEMLOCK_RANGE
_POSIX_MEMORY_PROTECTION
_POSIX_MESSAGE_PASSING
_POSIX_MONOTONIC_CLOCK
_POSIX_NO_TRUNC
_POSIX_PRIORITIZED_IO
_POSIX_PRIORITY_SCHEDULING
_POSIX_RAW_SOCKETS
_POSIX_READER_WRITER_LOCKS
_POSIX_REALTIME_SIGNALS
_POSIX_REENTRANT_FUNCTIONS
_POSIX_REGEXP
_POSIX_SAVED_IDS
_POSIX_SEMAPHORES
_POSIX_SHARED_MEMORY_OBJECTS
_POSIX_SHELL
_POSIX_SOURCE
_POSIX_SPAWN
_POSIX_SPIN_LOCKS
_POSIX_SPORADIC_SERVER
_POSIX_SYNCHRONIZED_IO
_POSIX_THREADS
_POSIX_THREAD_ATTR_STACKADDR
_POSIX_THREAD_ATTR_STACKSIZE
_POSIX_THREAD_CPUTIME
_POSIX_THREAD_PRIORITY_SCHEDULING
_POSIX_THREAD_PRIO_INHERIT
_POSIX_THREAD_PRIO_PROTECT
_POSIX_THREAD_PROCESS_SHARED
_POSIX_THREAD_ROBUST_PRIO_INHERIT
_POSIX_THREAD_ROBUST_PRIO_PROTECT
_POSIX_THREAD_SAFE_FUNCTIONS
_POSIX_THREAD_SPORADIC_SERVER
_POSIX_TIMEOUTS
_POSIX_TIMERS
_POSIX_TRACE
_POSIX_TRACE_EVENT_FILTER
_POSIX_TRACE_INHERIT
_POSIX_TRACE_LOG
_POSIX_TYPED_MEMORY_OBJECTS
_POSIX_V6_LP64_OFF64
_POSIX_V6_LPBIG_OFFBIG
_POSIX_V7_LP64_OFF64
_POSIX_V7_LPBIG_OFFBIG
_POSIX_VDISABLE
_POSIX_VERSION
_SC_2_CHAR_TERM
_SC_2_C_BIND
_SC_2_C_DEV
_SC_2_C_VERSION
_SC_2_FORT_DEV
_SC_2_FORT_RUN
_SC_2_LOCALEDEF
_SC_2_PBS
_SC_2_PBS_ACCOUNTING
_SC_2_PBS_CHECKPOINT
_SC_2_PBS_LOCATE
_SC_2_PBS_MESSAGE
_SC_2_PBS_TRACK
_SC_2_SW_DEV
_SC_2_UPE
_SC_2_VERSION
_SC_ADVISORY_INFO
_SC_AIO_LISTIO_MAX
_SC_AIO_MAX
_SC_AIO_PRIO_DELTA_MAX
_SC_ARG_MAX
_SC_ASYNCHRONOUS_IO
_SC_ATEXIT_MAX
_SC_AVPHYS_PAGES
_SC_BARRIERS
_SC_BASE
_SC_BC_BASE_MAX
_SC_BC_DIM_MAX
_SC_BC_SCALE_MAX
_SC_BC_STRING_MAX
_SC_CHARCLASS_NAME_MAX
_SC_CHAR_BIT
_SC_CHAR_MAX
_SC_CHAR_MIN
_SC_CHILD_MAX
_SC_CLK_TCK
_SC_CLOCK_SELECTION
_SC_COLL_WEIGHTS_MAX
_SC_CPUTIME
_SC_C_LANG_SUPPORT
_SC_C_LANG_SUPPORT_R
_SC_DELAYTIMER_MAX
_SC_DEVICE_IO
_SC_DEVICE_SPECIFIC
_SC_DEVICE_SPECIFIC_R
_SC_EQUIV_CLASS_MAX
_SC_EXPR_NEST_MAX
_SC_FD_MGMT
_SC_FIFO
_SC_FILE_ATTRIBUTES
_SC_FILE_LOCKING
_SC_FILE_SYSTEM
_SC_FSYNC
_SC_GETGR_R_SIZE_MAX
_SC_GETPW_R_SIZE_MAX
_SC_HOST_NAME_MAX
_SC_INT_MAX
_SC_INT_MIN
_SC_IOV_MAX
_SC_IPV6
_SC_JOB_CONTROL
_SC_LEVEL1_DCACHE_ASSOC
_SC_LEVEL1_DCACHE_LINESIZE
_SC_LEVEL1_DCACHE_SIZE
_SC_LEVEL1_ICACHE_ASSOC
_SC_LEVEL1_ICACHE_LINESIZE
_SC_LEVEL1_ICACHE_SIZE
_SC_LEVEL2_CACHE_ASSOC
_SC_LEVEL2_CACHE_LINESIZE
_SC_LEVEL2_CACHE_SIZE
_SC_LEVEL3_CACHE_ASSOC
_SC_LEVEL3_CACHE_LINESIZE
_SC_LEVEL3_CACHE_SIZE
_SC_LEVEL4_CACHE_ASSOC
_SC_LEVEL4_CACHE_LINESIZE
_SC_LEVEL4_CACHE_SIZE
_SC_LINE_MAX
_SC_LOGIN_NAME_MAX
_SC_LONG_BIT
_SC_MAPPED_FILES
_SC_MB_LEN_MAX
_SC_MEMLOCK
_SC_MEMLOCK_RANGE
_SC_MEMORY_PROTECTION
_SC_MESSAGE_PASSING
_SC_MINSIGSTKSZ
_SC_MONOTONIC_CLOCK
_SC_MQ_OPEN_MAX
_SC_MQ_PRIO_MAX
_SC_MULTI_PROCESS
_SC_NETWORKING
_SC_NGROUPS_MAX
_SC_NL_ARGMAX
_SC_NL_LANGMAX
_SC_NL_MSGMAX
_SC_NL_NMAX
_SC_NL_SETMAX
_SC_NL_TEXTMAX
_SC_NPROCESSORS_CONF
_SC_NPROCESSORS_ONLN
_SC_NZERO
_SC_OPEN_MAX
_SC_PAGESIZE
_SC_PASS_MAX
_SC_PHYS_PAGES
_SC_PII
_SC_PII_INTERNET
_SC_PII_INTERNET_DGRAM
_SC_PII_INTERNET_STREAM
_SC_PII_OSI
_SC_PII_OSI_CLTS
_SC_PII_OSI_COTS
_SC_PII_OSI_M
_SC_PII_SOCKET
_SC_PII_XTI
_SC_PIPE
_SC_POLL
_SC_PRIORITIZED_IO
_SC_PRIORITY_SCHEDULING
_SC_RAW_SOCKETS
_SC_READER_WRITER_LOCKS
_SC_REALTIME_SIGNALS
_SC_REGEXP
_SC_REGEX_VERSION
_SC_RE_DUP_MAX
_SC_RTSIG_MAX
_SC_SAVED_IDS
_SC_SCHAR_MAX
_SC_SCHAR_MIN
_SC_SELECT
_SC_SEMAPHORES
_SC_SEM_NSEMS_MAX
_SC_SEM_VALUE_MAX
_SC_SHARED_MEMORY_OBJECTS
_SC_SHELL
_SC_SHRT_MAX
_SC_SHRT_MIN
_SC_SIGNALS
_SC_SIGQUEUE_MAX
_SC_SIGSTKSZ
_SC_SINGLE_PROCESS
_SC_SPAWN
_SC_SPIN_LOCKS
_SC_SPORADIC_SERVER
_SC_SSIZE_MAX
_SC_SS_REPL_MAX
_SC_STREAMS
_SC_STREAM_MAX
_SC_SYMLOOP_MAX
_SC_SYNCHRONIZED_IO
_SC_SYSTEM_DATABASE
_SC_SYSTEM_DATABASE_R
_SC_THREADS
_SC_THREAD_ATTR_STACKADDR
_SC_THREAD_ATTR_STACKSIZE
_SC_THREAD_CPUTIME
_SC_THREAD_DESTRUCTOR_ITERATIONS
_SC_THREAD_KEYS_MAX
_SC_THREAD_PRIORITY_SCHEDULING
_SC_THREAD_PRIO_INHERIT
_SC_THREAD_PRIO_PROTECT
_SC_THREAD_PROCESS_SHARED
_SC_THREAD_ROBUST_PRIO_INHERIT
_SC_THREAD_ROBUST_PRIO_PROTECT
_SC_THREAD_SAFE_FUNCTIONS
_SC_THREAD_SPORADIC_SERVER
_SC_THREAD_STACK_MIN
_SC_THREAD_THREADS_MAX
_SC_TIMEOUTS
_SC_TIMERS
_SC_TIMER_MAX
_SC_TRACE
_SC_TRACE_EVENT_FILTER
_SC_TRACE_EVENT_NAME_MAX
_SC_TRACE_INHERIT
_SC_TRACE_LOG
_SC_TRACE_NAME_MAX
_SC_TRACE_SYS_MAX
_SC_TRACE_USER_EVENT_MAX
_SC_TTY_NAME_MAX
_SC_TYPED_MEMORY_OBJECTS
_SC_TZNAME_MAX
_SC_T_IOV_MAX
_SC_UCHAR_MAX
_SC_UINT_MAX
_SC_UIO_MAXIOV
_SC_ULONG_MAX
_SC_USER_GROUPS
_SC_USER_GROUPS_R
_SC_USHRT_MAX
_SC_V6_ILP32_OFF32
_SC_V6_ILP32_OFFBIG
_SC_V6_LP64_OFF64
_SC_V6_LPBIG_OFFBIG
_SC_V7_ILP32_OFF32
_SC_V7_ILP32_OFFBIG
_SC_V7_LP64_OFF64
_SC_V7_LPBIG_OFFBIG
_SC_VERSION
_SC_WORD_BIT
_SC_XBS5_ILP32_OFF32
_SC_XBS5_ILP32_OFFBIG
_SC_XBS5_LP64_OFF64
_SC_XBS5_LPBIG_OFFBIG
_SC_XOPEN_CRYPT
_SC_XOPEN_ENH_I18N
_SC_XOPEN_LEGACY
_SC_XOPEN_REALTIME
_SC_XOPEN_REALTIME_THREADS
_SC_XOPEN_SHM
_SC_XOPEN_STREAMS
_SC_XOPEN_UNIX
_SC_XOPEN_VERSION
_SC_XOPEN_XCU_VERSION
_SC_XOPEN_XPG2
_SC_XOPEN_XPG3
_SC_XOPEN_XPG4
_STDC_PREDEF_H
_STDINT_H
_STRUCT_TIMESPEC
_SYS_CDEFS_H
_SYS_EPOLL_H
_SYS_SELECT_H
_SYS_TIME_H
_SYS_TYPES_H
_THREAD_MUTEX_INTERNAL_H
_THREAD_SHARED_TYPES_H
_UNISTD_H
_XBS5_LP64_OFF64
_XBS5_LPBIG_OFFBIG
_XOPEN_ENH_I18N
_XOPEN_LEGACY
_XOPEN_REALTIME
_XOPEN_REALTIME_THREADS
_XOPEN_SHM
_XOPEN_SOURCE
_XOPEN_SOURCE_EXTENDED
_XOPEN_UNIX
_XOPEN_VERSION
_XOPEN_XCU_VERSION
_XOPEN_XPG2
_XOPEN_XPG3
_XOPEN_XPG4
__BIG_ENDIAN
__BIT_TYPES_DEFINED__
__BYTE_ORDER
__FD_SETSIZE
__FLOAT_WORD_ORDER
__GLIBC_MINOR__
__GLIBC_USE_C2X_STRTOL
__GLIBC_USE_DEPRECATED_GETS
__GLIBC_USE_DEPRECATED_SCANF
__GLIBC_USE_IEC_60559_BFP_EXT
__GLIBC_USE_IEC_60559_BFP_EXT_C2X
__GLIBC_USE_IEC_60559_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT_C2X
__GLIBC_USE_IEC_60559_TYPES_EXT
__GLIBC_USE_ISOC2X
__GLIBC_USE_LIB_EXT2
__GLIBC__
__GNU_LIBRARY__
__HAVE_GENERIC_SELECTION
__ILP32_OFF32_CFLAGS
__ILP32_OFF32_LDFLAGS
__ILP32_OFFBIG_CFLAGS
__ILP32_OFFBIG_LDFLAGS
__INO_T_MATCHES_INO64_T
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI
__LITTLE_ENDIAN
__LP64_OFF64_CFLAGS
__LP64_OFF64_LDFLAGS
__OFF_T_MATCHES_OFF64_T
__PDP_ENDIAN
__POSIX2_THIS_VERSION
__PTHREAD_MUTEX_HAVE_PREV
__RLIM_T_MATCHES_RLIM64_T
__SIZEOF_PTHREAD_ATTR_T
__SIZEOF_PTHREAD_BARRIERATTR_T
__SIZEOF_PTHREAD_BARRIER_T
__SIZEOF_PTHREAD_CONDATTR_T
__SIZEOF_PTHREAD_COND_T
__SIZEOF_PTHREAD_MUTEXATTR_T
__SIZEOF_PTHREAD_MUTEX_T
__SIZEOF_PTHREAD_RWLOCKATTR_T
__SIZEOF_PTHREAD_RWLOCK_T
__STATFS_MATCHES_STATFS64
__STDC_IEC_559_COMPLEX__
__STDC_IEC_559__
__STDC_IEC_60559_BFP__
__STDC_IEC_60559_COMPLEX__
__STDC_ISO_10646__
__SYSCALL_WORDSIZE
__TIMESIZE
__USE_ATFILE
__USE_DYNAMIC_STACK_SIZE
__USE_FORTIFY_LEVEL
__USE_GNU
__USE_ISOC11
__USE_ISOC95
__USE_ISOC99
__USE_ISOCXX11
__USE_LARGEFILE
__USE_LARGEFILE64
__USE_MISC
__USE_POSIX
__USE_POSIX2
__USE_POSIX199309
__USE_POSIX199506
__USE_UNIX98
__USE_XOPEN
__USE_XOPEN2K
__USE_XOPEN2K8
__USE_XOPEN2K8XSI
__USE_XOPEN2KXSI
__USE_XOPEN_EXTENDED
__WORDSIZE
__WORDSIZE_TIME64_COMPAT32
__bool_true_false_are_defined
__clock_t_defined
__clockid_t_defined
__glibc_c99_flexarr_available
__have_pthread_attr_t
__itimer_which_ITIMER_PROF
__itimer_which_ITIMER_REAL
__itimer_which_ITIMER_VIRTUAL
__sigset_t_defined
__time_t_defined
__timer_t_defined
__timeval_defined
kBroadcastCodeSize
kMaxLidarCount

Statics

__environ
environ
optarg
opterr
optind
optopt

Functions

DisableLivoxLidarFov
Disable LiDAR fov. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
DisableLivoxLidarFusaFunciont
Disable LiDAR fusa function. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
DisableLivoxLidarGlassHeat
Disable glass heating functionality. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
DisableLivoxLidarImuData
Disable LiDAR imu data. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
DisableLivoxLidarPointSend
Disable LiDAR point send. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
DisableLivoxSdkConsoleLogger
DisableLivoxLidar console log output.
EnableLivoxLidarFov
Enable LiDAR fov cfg1. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
EnableLivoxLidarFusaFunciont
Enable LiDAR fusa function. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
EnableLivoxLidarGlassHeat
Enable glass heating functionality. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
EnableLivoxLidarImuData
Enable LiDAR imu data. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
EnableLivoxLidarPointSend
Enbale LiDAR point send. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
GetLivoxLidarSdkVer
Return SDK’s version information in a numeric form. @param version Pointer to a version structure for returning the version information.
LivoxLidarAddCmdObserver
Add the lidar command data observer. @param handle device handle. @param client_data user data associated with the command.
LivoxLidarAddPointCloudObserver
Set the point cloud observer. @param cb callback to receive Status Info. @param client_data user data associated with the command.
LivoxLidarRemoveCmdObserver
Remove the lidar command data observer.
LivoxLidarRemovePointCloudObserver
remove point cloud observer. @param id the observer id.
LivoxLidarRequestReboot
Reboot lidar. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarRequestReset
Reset LiDAR. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarSdkInit
Initialize the SDK. @return true if successfully initialized, otherwise false.
LivoxLidarSdkStart
Start the device scanning routine which runs on a separate thread. @return true if successfully started, otherwise false.
LivoxLidarSdkUninit
Uninitialize the SDK.
LivoxLidarStartLogger
Start logger. Currently, only setting real-time log is supported. @param handle device handle. @param log_type The type of log file that has been configured. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarStopLogger
Start logger. Currently, only setting real-time log is supported. @param handle device handle. @param log_type The type of log file that has been configured. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
QueryLivoxLidarFirmwareVer
QueryLivoxLidarFwType
QueryLivoxLidarInternalInfo
SaveLivoxLidarSdkLoggerFile
Save the log file.
SetLivoxLidarBlindSpot
Set LiDAR blind spot. @param handle device handle. @param blind_spot blind spot. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarDebugPointCloud
Set LiDAR debug point cloud switch. @param handle device handle. @param enable true for enabling debug point cloud @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error codes.
SetLivoxLidarDetectMode
Set LiDAR detect mode. @param handle device handle. @param mode detect mode @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarDualEmit
Set LiDAR dual emit. @param handle device handle. @param enable if set dual emit the enable is true, else the enable is false @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarFovCfg0
Set LiDAR fov cfg0. @param handle device handle. @param fov_cfg0 fov cfg. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarFovCfg1
Set LiDAR fov. @param handle device handle. @param fov_cfg1 fov cfg. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarFuncIOCfg
Set LiDAR func io cfg. @param handle device handle. @param func_io_cfg func io cfg; 0:IN0,1:IN1, 2:OUT0, 3:OUT1;Mid360 lidar 8, 10, 12, 11 @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarGlassHeat
Set LiDAR glass heat. @param handle device handle. @param glass_heat lidar glass heat. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarImuDataCallback
Set the callback to receive IMU data. @param cb callback to receive Status Info. @param client_data user data associated with the command.
SetLivoxLidarImuDataHostIPCfg
Set LiDAR imu data host ip info. @param handle device handle. @param host_imu_ipcfg lidar ip info. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarInfoCallback
Set the callback to receive Status Info. @param cb callback to receive Status Info. @param client_data user data associated with the command.
SetLivoxLidarInfoChangeCallback
Set the callback to receive Status Info. @param cb callback to receive Status Info. @param client_data user data associated with the command.
SetLivoxLidarInstallAttitude
Get LiDAR extrinsic parameters. @param handle device handle. @param install_attitude extrinsic parameters. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarIp
Set LiDAR Ip info. @param handle device handle. @param ipconfig lidar ip info. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarPclDataType
Set LiDAR pcl data type. @param handle device handle. @param data_type the type to change, the val:kLivoxLidarCartesianCoordinateHighData, kLivoxLidarCartesianCoordinateLowData, kLivoxLidarSphericalCoordinateData @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarPointCloudCallBack
Set the callback to receive point cloud data. @param handle device handle. @param client_data user data associated with the command.
SetLivoxLidarPointDataHostIPCfg
Set LiDAR point cloud host ip info. @param handle device handle. @param host_point_ipcfg lidar ip info. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarRmcSyncTime
Set LiDAR GPS “GPRMC” string to synchronize the time. @param handle device handle. @param rmc GPS “GPRMC” string. @param rmc_length GPS “GPRMC” string length. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error codes.
SetLivoxLidarScanPattern
Set LiDAR sacn pattern. @param handle device handle. @param scan_type the type to change, the val:kLivoxLidarScanPatternRepetive, kLivoxLidarScanPatternNoneRepetive @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarStateInfoHostIPCfg
Set LiDAR state Ip info. @param handle device handle. @param host_state_info_ipcfg lidar ip info. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarUpgradeFirmwarePath
Start the device scanning routine which runs on a separate thread. @return true if successfully Open firmware file path, otherwise false.
SetLivoxLidarUpgradeProgressCallback
SetLivoxLidarWorkMode
Set LiDAR work mode. @param handle device handle. @param work_mode lidar work mode. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
SetLivoxLidarWorkModeAfterBoot
Set LiDAR work mode after boot. @param handle device handle. @param work_mode lidar work mode after boot. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
StartForcedHeating
Enable LiDAR force heat function. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
StopForcedHeating
Disable LiDAR force heat function. @param handle device handle. @param cb callback for the command. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
UpgradeLivoxLidars
_Fork
__getpgid
_exit
access
acct
adjtime
alarm
brk
chdir
chown
chroot
close
close_range
closefrom
confstr
copy_file_range
crypt
daemon
dup
dup2
dup3
eaccess
endusershell
epoll_create
epoll_create1
epoll_ctl
epoll_pwait
epoll_pwait2
epoll_wait
euidaccess
execl
execle
execlp
execv
execve
execveat
execvp
execvpe
faccessat
fchdir
fchown
fchownat
fdatasync
fexecve
fork
fpathconf
fsync
ftruncate
ftruncate64
futimes
futimesat
get_current_dir_name
getcwd
getdomainname
getdtablesize
getegid
getentropy
geteuid
getgid
getgroups
gethostid
gethostname
getitimer
getlogin
getlogin_r
getopt
getpagesize
getpass
getpgid
getpgrp
getpid
getppid
getresgid
getresuid
getsid
gettid
gettimeofday
getuid
getusershell
getwd
group_member
isatty
lchown
link
linkat
lockf
lockf64
lseek
lseek64
lutimes
nice
pathconf
pause
pipe
pipe2
pread
pread64
profil
pselect
pwrite
pwrite64
read
readlink
readlinkat
revoke
rmdir
sbrk
select
setdomainname
setegid
seteuid
setgid
sethostid
sethostname
setitimer
setlogin
setpgid
setpgrp
setregid
setresgid
setresuid
setreuid
setsid
settimeofday
setuid
setusershell
sleep
swab
symlink
symlinkat
sync
syncfs
syscall
sysconf
tcgetpgrp
tcsetpgrp
truncate
truncate64
ttyname
ttyname_r
ttyslot
ualarm
unlink
unlinkat
usleep
utimes
vfork
vhangup
write

Type Aliases

EPOLL_EVENTS
LivoxLidarAsyncControlCallback
Callback function for receiving response from the lidar on the configuration of parameter. @param status status info. @param response lidar return code and error key. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarCmdObserverCallBack
Callback function for receiving point cloud data. @param handle device handle. @param data device’s command data. @param client_data user data associated with the command.
LivoxLidarDetectMode
LivoxLidarDeviceType
Device type.
LivoxLidarFsmEvent
LivoxLidarFsmState
Upgrade related data struct
LivoxLidarGlassHeat
LivoxLidarImuDataCallback
Callback function for receiving IMU data. @param data device’s data. @param data_num number of IMU data. @param client_data user data associated with the command.
LivoxLidarInfoCallback
Callback function for receiving Status Info. @param status_info status info. @param client_data user data associated with the command.
LivoxLidarInfoChangeCallback
Callback function for receiving Status Info. @param status status info. @param client_data user data associated with the command.
LivoxLidarLogType
LivoxLidarLoggerCallback
Callback function for receiving the log setting response from lidar. @param status status info. @param response lidar return code. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarPointCloudCallBack
Callback function for receiving point cloud data. @param handle device handle. @param data device’s data. @param data_num number of points in data. @param client_data user data associated with the command.
LivoxLidarPointCloudObserver
Callback function for point cloud observer. @param handle device handle. @param data device’s data. @param data_num number of points in data. @param client_data user data associated with the command.
LivoxLidarPointDataType
LivoxLidarPointFrameRate
LivoxLidarRebootCallback
Callback function for receiving the Reboot setting response from lidar. @param status status info. @param response lidar return code. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarResetCallback
Callback function for receiving the reset setting response from lidar. @param status status info. @param response lidar return code. @param client_data user data associated with the command. @return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
LivoxLidarRmcSyncTimeCallBack
Callback function for receiving point cloud data. @param status status info. @param handle device handle. @param data device’s command data. @param client_data user data associated with the command.
LivoxLidarScanPattern
LivoxLidarStatus
LivoxLidarWorkMode
LivoxLidarWorkModeAfterBoot
OnLivoxLidarUpgradeProgressCallback
ParamKeyName
QueryLivoxLidarInternalInfoCallback
__blkcnt64_t
__blkcnt_t
__blksize_t
__caddr_t
__clock_t
__clockid_t
__daddr_t
__dev_t
__fd_mask
__fsblkcnt64_t
__fsblkcnt_t
__fsfilcnt64_t
__fsfilcnt_t
__fsword_t
__gid_t
__id_t
__ino64_t
__ino_t
__int8_t
__int16_t
__int32_t
__int64_t
__int_least8_t
__int_least16_t
__int_least32_t
__int_least64_t
__intmax_t
__intptr_t
__itimer_which
__itimer_which_t
__key_t
__loff_t
__mode_t
__nlink_t
__off64_t
__off_t
__pid_t
__pthread_list_t
__pthread_slist_t
__quad_t
__rlim64_t
__rlim_t
__sig_atomic_t
__socklen_t
__ssize_t
__suseconds64_t
__suseconds_t
__syscall_slong_t
__syscall_ulong_t
__thrd_t
__time_t
__timer_t
__tss_t
__u_char
__u_int
__u_long
__u_quad_t
__u_short
__uid_t
__uint8_t
__uint16_t
__uint32_t
__uint64_t
__uint_least8_t
__uint_least16_t
__uint_least32_t
__uint_least64_t
__uintmax_t
__useconds_t
_bindgen_ty_1
_bindgen_ty_2
_bindgen_ty_3
_bindgen_ty_4
blkcnt64_t
blkcnt_t
blksize_t
caddr_t
clock_t
clockid_t
daddr_t
dev_t
epoll_data_t
fd_mask
fsblkcnt64_t
fsblkcnt_t
fsfilcnt64_t
fsfilcnt_t
fsid_t
gid_t
id_t
ino64_t
ino_t
int_fast8_t
int_fast16_t
int_fast32_t
int_fast64_t
int_least8_t
int_least16_t
int_least32_t
int_least64_t
intmax_t
key_t
livox_status
Fuction return value defination, refer to \ref LivoxStatus.
loff_t
mode_t
nlink_t
off64_t
off_t
pid_t
pthread_key_t
pthread_once_t
pthread_spinlock_t
pthread_t
quad_t
register_t
sigset_t
socklen_t
suseconds_t
time_t
timer_t
u_char
u_int
u_int8_t
u_int16_t
u_int32_t
u_int64_t
u_long
u_quad_t
u_short
uid_t
uint
uint_fast8_t
uint_fast16_t
uint_fast32_t
uint_fast64_t
uint_least8_t
uint_least16_t
uint_least32_t
uint_least64_t
uintmax_t
ulong
useconds_t
ushort

Unions

__atomic_wide_counter
epoll_data
pthread_attr_t
pthread_barrier_t
pthread_barrierattr_t
pthread_cond_t
pthread_condattr_t
pthread_mutex_t
pthread_mutexattr_t
pthread_rwlock_t
pthread_rwlockattr_t