Disable LiDAR fov.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Disable LiDAR fusa function.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Disable glass heating functionality.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Disable LiDAR imu data.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Disable LiDAR point send.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Enable LiDAR fov cfg1.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Enable LiDAR fusa function.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Enable glass heating functionality.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Enable LiDAR imu data.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Enbale LiDAR point send.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Reboot lidar.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Reset LiDAR.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Start logger. Currently, only setting real-time log is supported.
@param handle device handle.
@param log_type The type of log file that has been configured.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Start logger. Currently, only setting real-time log is supported.
@param handle device handle.
@param log_type The type of log file that has been configured.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR blind spot.
@param handle device handle.
@param blind_spot blind spot.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR debug point cloud switch.
@param handle device handle.
@param enable true for enabling debug point cloud
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error codes.
Set LiDAR detect mode.
@param handle device handle.
@param mode detect mode
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR dual emit.
@param handle device handle.
@param enable if set dual emit the enable is true, else the enable is false
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR fov cfg0.
@param handle device handle.
@param fov_cfg0 fov cfg.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR fov.
@param handle device handle.
@param fov_cfg1 fov cfg.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR func io cfg.
@param handle device handle.
@param func_io_cfg func io cfg; 0:IN0,1:IN1, 2:OUT0, 3:OUT1;Mid360 lidar 8, 10, 12, 11
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR glass heat.
@param handle device handle.
@param glass_heat lidar glass heat.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR imu data host ip info.
@param handle device handle.
@param host_imu_ipcfg lidar ip info.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Get LiDAR extrinsic parameters.
@param handle device handle.
@param install_attitude extrinsic parameters.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR Ip info.
@param handle device handle.
@param ipconfig lidar ip info.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR pcl data type.
@param handle device handle.
@param data_type the type to change, the val:kLivoxLidarCartesianCoordinateHighData,
kLivoxLidarCartesianCoordinateLowData,
kLivoxLidarSphericalCoordinateData
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR point cloud host ip info.
@param handle device handle.
@param host_point_ipcfg lidar ip info.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR GPS “GPRMC” string to synchronize the time.
@param handle device handle.
@param rmc GPS “GPRMC” string.
@param rmc_length GPS “GPRMC” string length.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error codes.
Set LiDAR sacn pattern.
@param handle device handle.
@param scan_type the type to change, the val:kLivoxLidarScanPatternRepetive,
kLivoxLidarScanPatternNoneRepetive
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR state Ip info.
@param handle device handle.
@param host_state_info_ipcfg lidar ip info.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR work mode.
@param handle device handle.
@param work_mode lidar work mode.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Set LiDAR work mode after boot.
@param handle device handle.
@param work_mode lidar work mode after boot.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Enable LiDAR force heat function.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Disable LiDAR force heat function.
@param handle device handle.
@param cb callback for the command.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Callback function for receiving response from the lidar on the configuration of parameter.
@param status status info.
@param response lidar return code and error key.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Callback function for receiving point cloud data.
@param handle device handle.
@param data device’s command data.
@param client_data user data associated with the command.
Callback function for receiving IMU data.
@param data device’s data.
@param data_num number of IMU data.
@param client_data user data associated with the command.
Callback function for receiving the log setting response from lidar.
@param status status info.
@param response lidar return code.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Callback function for receiving point cloud data.
@param handle device handle.
@param data device’s data.
@param data_num number of points in data.
@param client_data user data associated with the command.
Callback function for point cloud observer.
@param handle device handle.
@param data device’s data.
@param data_num number of points in data.
@param client_data user data associated with the command.
Callback function for receiving the Reboot setting response from lidar.
@param status status info.
@param response lidar return code.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Callback function for receiving the reset setting response from lidar.
@param status status info.
@param response lidar return code.
@param client_data user data associated with the command.
@return kStatusSuccess on successful return, see \ref LivoxStatus for other error code.
Callback function for receiving point cloud data.
@param status status info.
@param handle device handle.
@param data device’s command data.
@param client_data user data associated with the command.